summaryrefslogtreecommitdiff
path: root/src/xfont.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/xfont.c')
-rw-r--r--src/xfont.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/xfont.c b/src/xfont.c
index 8b1e37aa146..73f1e130be0 100644
--- a/src/xfont.c
+++ b/src/xfont.c
@@ -272,8 +272,8 @@ xfont_chars_supported (Lisp_Object chars, XFontStruct *xfont,
return 0;
}
-/* A hash table recoding which font supports which scritps. Each key
- is a vector of characteristic font propertis FOUNDRY to WIDTH and
+/* A hash table recoding which font supports which scripts. Each key
+ is a vector of characteristic font properties FOUNDRY to WIDTH and
ADDSTYLE, and each value is a list of script symbols.
We assume that fonts that have the same value in the above
@@ -281,7 +281,7 @@ xfont_chars_supported (Lisp_Object chars, XFontStruct *xfont,
static Lisp_Object xfont_scripts_cache;
/* Re-usable vector to store characteristic font properites. */
static Lisp_Object xfont_scratch_props;
/* Return a list of scripts supported by the font of FONTNAME whose
@@ -281,7 +281,7 @@ xfont_chars_supported (Lisp_Object chars, XFontStruct *xfont,
static Lisp_Object xfont_scripts_cache;
-/* Re-usable vector to store characteristic font properites. */
+/* Re-usable vector to store characteristic font properties. */
static Lisp_Object xfont_scratch_props;
/* Return a list of scripts supported by the font of FONTNAME whose